@@ -17,7 +17,7 @@ SLAVE_RUNNER=/usr/bin/buildslave
 
 . /lib/lsb/init-functions
 
-# Source buildslave configuration 
+# Source buildslave configuration
 [[ -r /etc/default/buildslave ]] && . /etc/default/buildslave
 #[[ -r /etc/sysconfig/buildslave ]] && . /etc/sysconfig/buildslave
 
@@ -26,7 +26,7 @@ SLAVE_RUNNER=/usr/bin/buildslave
 #SLAVE_NAME[1]="buildslave #1"         # short name printed on start/stop
 #SLAVE_USER[1]="buildbot"              # user to run slave as
 #SLAVE_BASEDIR[1]=""                   # basedir to slave (absolute path)
-#SLAVE_OPTIONS[1]=""                   # buildbot options  
+#SLAVE_OPTIONS[1]=""                   # buildbot options
 #SLAVE_PREFIXCMD[1]=""                 # prefix command, i.e. nice, linux32, dchroot
 
 if [[ ! -x ${SLAVE_RUNNER} ]]; then
@@ -34,13 +34,58 @@ if [[ ! -x ${SLAVE_RUNNER} ]]; then
     exit 1
 fi
 
+function is_enabled() {
+    ANSWER=`echo $1|tr "[:upper:]" "[:lower:]"`
+    [[ "$ANSWER" == "yes" ]] || [[ "$ANSWER" == "true" ]] || [[ "$ANSWER" ==  "1" ]]
+    return $?
+}
+
+function is_disabled() {
+    ANSWER=`echo $1|tr "[:upper:]" "[:lower:]"`
+    [[ "$ANSWER" == "no" ]] || [[ "$ANSWER" == "false" ]] || [[ "$ANSWER" ==  "0" ]]
+    return $?
+}
+
+
+function slave_config_valid() {
+    # Function validates buildmaster instance startup variables based on array
+    # index
+    local errors=0
+    local index=$1
+
+    if ! is_enabled "${SLAVE_ENABLED[$index]}" && ! is_disabled "${SLAVE_ENABLED[$index]}" ; then
+        log_warning_msg "buildmaster #${i}: invalid enabled status"
+        errors=$(($errors+1))
+    fi
+
+    if [[ -z ${SLAVE_NAME[$index]} ]]; then
+        log_failure_msg "buildmaster #${i}: no name"
+        errors=$(($errors+1))
+    fi
+
+    if [[ -z ${SLAVE_USER[$index]} ]]; then
+        log_failure_msg "buildmaster #${i}: no run user specified"
+        errors=$( ($errors+1) )
+    elif ! getent passwd ${SLAVE_USER[$index]} >/dev/null; then
+        log_failure_msg "buildmaster #${i}: unknown user ${SLAVE_USER[$index]}"
+        errors=$(($errors+1))
+    fi
+
+    if [[ ! -d "${SLAVE_BASEDIR[$index]}" ]]; then
+        log_failure_msg "buildmaster ${i}: basedir does not exist ${SLAVE_BASEDIR[$index]}"
+        errors=$(($errors+1))
+    fi
+
+    return $errors
+}
+
 function check_config() {
     itemcount="${#SLAVE_ENABLED[@]}
                ${#SLAVE_NAME[@]}
                ${#SLAVE_USER[@]}
                ${#SLAVE_BASEDIR[@]}
                ${#SLAVE_OPTIONS[@]}
-               ${#SLAVE_PREFIXCMD[@]}" 
+               ${#SLAVE_PREFIXCMD[@]}"
 
     if [[ $(echo "$itemcount" | tr -d ' ' | sort -u | wc -l) -ne 1 ]]; then
         log_failure_msg "SLAVE_* arrays must have an equal number of elements!"
@@ -49,28 +94,12 @@ function check_config() {
 
     errors=0
     for i in $( seq ${#SLAVE_ENABLED[@]} ); do
-        if [[ ${SLAVE_ENABLED[$i]} -ne 0 ]]; then 
-            log_failure_msg "buildslave #${i}: unknown run status"
-            errors=$(($errors+1))
-        fi
-
-        if [[ -z ${SLAVE_NAME[$i]} ]]; then
-            log_failure_msg "buildslave #${i}: no name"
-            errors=$(($errors+1))
-        fi
-
-        if [[ -z ${SLAVE_USER[$i]} ]]; then
-            log_failure_msg "buildslave #${i}: no run user specified"
-            errors=$( ($errors+1) )
-        elif ! getent passwd ${SLAVE_USER[$i]} >/dev/null; then
-            log_failure_msg "buildslave #${i}: unknown user ${SLAVE_USER[$i]}"
-            errors=$(($errors+1))
-        fi
-
-        if [[ ! -d "${SLAVE_BASEDIR[$i]}" ]]; then
-            log_failure_msg "buildslave ${i}: basedir does not exist ${SLAVE_BASEDIR[$i]}"
-            errors=$(($errors+1))
+        if is_disabled "${SLAVE_ENABLED[$i]}" ; then
+            log_warning_msg "buildslave #${i}: disabled"
+            continue
         fi
+        slave_config_valid $i
+        errors=$(($errors+$?))
     done
 
     [[ $errors == 0 ]]; return $?
@@ -83,7 +112,7 @@ function iscallable () { type $1 2>/dev/null | grep -q 'shell function'; }
 function slave_op () {
     op=$1 ; mi=$2
 
-    ${SLAVE_PREFIXCMD[$1]} \
+    ${SLAVE_PREFIXCMD[$mi]} \
     su -s /bin/sh \
     -c "$SLAVE_RUNNER $op --quiet ${SLAVE_OPTIONS[$mi]} ${SLAVE_BASEDIR[$mi]}" \
     - ${SLAVE_USER[$mi]}
@@ -93,7 +122,9 @@ function slave_op () {
 function do_op () {
     errors=0
     for i in $( seq ${#SLAVE_ENABLED[@]} ); do
-        [[ ${SLAVE_ENABLED[$i]} -ne 0 ]] && continue
+        if is_disabled "${SLAVE_ENABLED[$i]}" ; then
+            continue
+        fi
 
         # Some rhels don't come with all the lsb goodies
         if iscallable log_daemon_msg; then
